==> eolymp-0.10.49.tar.gz: eolymp-0.10.49/eolymp/atlas/__init__.py <==
from .suggestion_pb2 import *
from .solution_service_pb2 import *
from .scoring_service_http import *
from .problem_pb2 import *
from .testing_service_pb2 import *
from .editorial_service_http import *
from .atlas_http import *
from .problem_service_pb2 import *
from .solution_pb2 import *
from .attachment_pb2 import *
from .statement_pb2 import *
from .asset_service_pb2 import *
from .scoring_score_pb2 import *
from .attachment_service_http import *
from .testing_testset_pb2 import *
from .asset_service_http import *
from .bookmark_service_http import *
from .configuration_service_pb2 import *
from .scoring_service_pb2 import *
from .submission_service_http import *
from .editorial_pb2 import *
from .solution_service_http import *
from .configuration_service_http import *
from .editorial_service_pb2 import *
from .testing_config_pb2 import *
from .testing_service_http import *
from .code_template_service_pb2 import *
from .testing_feedback_pb2 import *
from .events_pb2 import *
from .testing_test_pb2 import *
from .code_template_pb2 import *
from .atlas_pb2 import *
from .version_pb2 import *
from .code_template_file_pb2 import *
from .suggestion_service_http import *
from .bookmark_service_pb2 import *
from .statement_service_http import *
from .problem_service_http import *
from .suggestion_service_pb2 import *
from .attachment_service_pb2 import *
from .submission_pb2 import *
from .testing_scoring_pb2 import *
from .code_template_service_http import *
from .statement_service_pb2 import *
from .snapshot_pb2 import *
from .submission_service_pb2 import *

==> eolymp-0.10.54.tar.gz: eolymp-0.10.54/eolymp/atlas/__init__.py <==
from .suggestion_pb2 import *
from .solution_service_pb2 import *
from .scoring_service_http import *
from .problem_pb2 import *
from .testing_service_pb2 import *
from .editorial_service_http import *
from .atlas_http import *
from .problem_service_pb2 import *
from .solution_pb2 import *
from .attachment_pb2 import *
from .statement_pb2 import *
from .scoring_score_pb2 import *
from .attachment_service_http import *
from .testing_testset_pb2 import *
from .bookmark_service_http import *
from .configuration_service_pb2 import *
from .scoring_service_pb2 import *
from .submission_service_http import *
from .editorial_pb2 import *
from .script_service_pb2 import *
from .solution_service_http import *
from .configuration_service_http import *
from .editorial_service_pb2 import *
from .testing_config_pb2 import *
from .testing_service_http import *
from .code_template_service_pb2 import *
from .testing_feedback_pb2 import *
from .events_pb2 import *
from .testing_test_pb2 import *
from .code_template_pb2 import *
from .atlas_pb2 import *
from .version_pb2 import *
from .script_pb2 import *
from .suggestion_service_http import *
from .bookmark_service_pb2 import *
from .statement_service_http import *
from .problem_service_http import *
from .suggestion_service_pb2 import *
from .attachment_service_pb2 import *
from .submission_pb2 import *
from .testing_scoring_pb2 import *
from .code_template_service_http import *
from .script_service_http import *
from .statement_service_pb2 import *
from .snapshot_pb2 import *
from .submission_service_pb2 import *
